@@ -558,6 +558,7 @@ int main(int argc, char *argv[])
 				usage(argv[0]);
 				return 1;
 			}
+			break;
 
 		case 'r':
 			rx_depth = strtol(optarg, NULL, 0);
@@ -592,7 +593,7 @@ int main(int argc, char *argv[])
 
 	dev_list = ibv_get_device_list(NULL);
 	if (!dev_list) {
-		fprintf(stderr, "No IB devices found\n");
+		perror("Failed to get IB devices list");
 		return 1;
 	}
 
